@@ -42,11 +42,14 @@ const (
 	SetterAuto      = "auto"
 	SetterGamma     = "gamma"
 	SetterBacklight = "backlight"
+	SetterDDCCI     = "ddcci"
+	SetterDRM       = "drm"
 )
 
 var logger = log.NewLogger("daemon/display/brightness")
 
 var helper backlight.Backlight
+var ddcciHelper backlight.DDCCI
 
 func InitBacklightHelper() {
 	var err error
@@ -55,9 +58,10 @@ func InitBacklightHelper() {
 		return
 	}
 	helper = backlight.NewBacklight(sysBus)
+	ddcciHelper = backlight.NewDDCCI(sysBus)
 }
 
-func Set(brightness float64, temperature int, setter string, isBuiltin bool, outputId uint32, conn *x.Conn) error {
+func Set(brightness float64, temperature int, setter string, isBuiltin bool, outputId uint32, conn *x.Conn, uuid string, edidBase64 string) error {
 	if brightness < 0 {
 		brightness = 0
 	} else if brightness > 1 {
@@ -97,9 +101,19 @@ func Set(brightness float64, temperature int, setter string, isBuiltin bool, out
 	case SetterBacklight:
 		setFn = setBlGamma
 	case SetterAuto:
+		// 自动检测仅自适应backlight和ddcci亮度调节
+		// 若两种都不支持，使用gamma调节
 		if isBuiltin && supportBacklight() {
 			setFn = setBlGamma
+		} else if supportDDCCIBrightness(edidBase64) {
+			return setDDCCIBrightness(brightness, edidBase64)
 		}
+	case SetterDDCCI:
+		return setDDCCIBrightness(brightness, edidBase64)
+	/* DRM 目前暂无检查是否支持接口，根据硬件驱动进行gsetting配置调节 */
+	case SetterDRM:
+		err := setBrigntnessByKwin(uuid, brightness)
+		return err
 		//case SetterGamma
 	}
 	return setFn()
@@ -238,3 +252,45 @@ func _setBacklight(value float64, controller *displayBl.Controller) error {
 		controller.Name, controller.MaxBrightness, value, br)
 	return helper.SetBrightness(0, backlightTypeDisplay, controller.Name, br)
 }
+
+//String outputs, const int brightness
+func setBrigntnessByKwin(output string, value float64) error {
+	logger.Info("setBrigntnessByKwin")
+	sessionBus, err := dbus.SessionBus()
+	if err != nil {
+		return err
+	}
+	sessionObj := sessionBus.Object("com.deepin.daemon.KWayland", "/com/deepin/daemon/KWayland/Output")
+	err = sessionObj.Call("com.deepin.daemon.KWayland.Output.setBrightness", 0, output, int32(value*100)).Store()
+	if err != nil {
+		logger.Warning(err)
+		return err
+	}
+	return nil
+}
+
+func supportDDCCIBrightness(edidBase64 string) bool {
+	res, err := ddcciHelper.CheckSupport(0, edidBase64)
+	if err != nil {
+		logger.Warningf("brightness: failed to check ddc/ci support: %v", err)
+		return false
+	}
+
+	return res
+}
+
+func setDDCCIBrightness(value float64, edidBase64 string) error {
+
+	percent := int32(value * 100)
+	logger.Debugf("brightness: ddcci set brightness %d", percent)
+	return ddcciHelper.SetBrightness(0, edidBase64, percent)
+}
+
+func getDDCCIBrightness(edidBase64 string) (float64, error) {
+	br, err := ddcciHelper.GetBrightness(0, edidBase64)
+	if err != nil {
+		return 1, err
+	} else {
+		return (float64(br) / 100.0), err
+	}
+}
